-- by modelleicher
--
-- www.schwabenmodding.de
--

indoorSoundModifier = {};

function indoorSoundModifier.prerequisitesPresent(specializations)
    return true;
end;

function indoorSoundModifier:load(savegame)

	
	self.soundModifiers = {};
	local i = 0;
	while true do
		if not hasXMLProperty(self.xmlFile, "vehicle.indoorSoundModifier.animPart("..i..")") then
			break;
		end;
		local modifier = {};
		modifier.id = getXMLString(self.xmlFile, "vehicle.indoorSoundModifier.animPart("..i..")#id");
		modifier.indoorLowpassGain = getXMLFloat(self.xmlFile, "vehicle.indoorSoundModifier.animPart("..i..")#lowpassGain");
		modifier.indoorVolumeFactor = getXMLFloat(self.xmlFile, "vehicle.indoorSoundModifier.animPart("..i..")#volumeFactor");
		table.insert(self.soundModifiers, modifier);
		i = i+1;
	end;
	
end;

function indoorSoundModifier:postLoad(savegame) 
	-- get the table index for each anim part relating to the modifier now, so it doesn't have to do that constantly in update
	for _, modifier in pairs(self.soundModifiers) do	
		for i=1, #self.animParts do
			local part = self.animParts[i];
			if part.id == modifier.id then
				modifier.partIndex = i; 
				break;
			end;
		end;
	end;
	
	-- backup motor sound sample values
	self.soundModifiers.motor = {};
	self.soundModifiers.motor.indoorVolumeFactor = self.sampleMotor.indoorVolumeFactor;
	self.soundModifiers.motor.indoorLowpassGain = self.sampleMotor.indoorLowpassGain;
	
	self.soundModifiers.motorRun = {};
	self.soundModifiers.motorRun.indoorVolumeFactor = self.sampleMotorRun.indoorVolumeFactor;
	self.soundModifiers.motorRun.indoorLowpassGain = self.sampleMotorRun.indoorLowpassGain;
	
	self.soundModifiers.motorLoad = {};
	self.soundModifiers.motorLoad.indoorVolumeFactor = self.sampleMotorLoad.indoorVolumeFactor;
	self.soundModifiers.motorLoad.indoorLowpassGain = self.sampleMotorLoad.indoorLowpassGain;
	
	self.soundModifiers.motorStart = {};
	self.soundModifiers.motorStart.indoorVolumeFactor = self.sampleMotorStart.indoorVolumeFactor;
	self.soundModifiers.motorStart.indoorLowpassGain = self.sampleMotorStart.indoorLowpassGain;
	
	self.soundModifiers.motorStop = {};
	self.soundModifiers.motorStop.indoorVolumeFactor = self.sampleMotorStop.indoorVolumeFactor;
	self.soundModifiers.motorStop.indoorLowpassGain = self.sampleMotorStop.indoorLowpassGain;
end;

function indoorSoundModifier:delete()

end;
function indoorSoundModifier:mouseEvent(posX, posY, isDown, isUp, button)
end;
function indoorSoundModifier:keyEvent(unicode, sym, modifier, isDown)
end;
function indoorSoundModifier:update(dt)
    if self:getIsActive() and self.isClient and self.isEntered then
	
		self.sampleMotor.indoorVolumeFactor = self.soundModifiers.motor.indoorVolumeFactor;
		self.sampleMotor.indoorLowpassGain = self.soundModifiers.motor.indoorLowpassGain;
				
		self.sampleMotorRun.indoorVolumeFactor = self.soundModifiers.motorRun.indoorVolumeFactor;
		self.sampleMotorRun.indoorLowpassGain = self.soundModifiers.motorRun.indoorLowpassGain;
		
		self.sampleMotorLoad.indoorVolumeFactor = self.soundModifiers.motorLoad.indoorVolumeFactor;
		self.sampleMotorLoad.indoorLowpassGain = self.soundModifiers.motorLoad.indoorLowpassGain;
		
		self.sampleMotorStart.indoorVolumeFactor = self.soundModifiers.motorStart.indoorVolumeFactor;
		self.sampleMotorStart.indoorLowpassGain = self.soundModifiers.motorStart.indoorLowpassGain;
		
		self.sampleMotorStop.indoorVolumeFactor = self.soundModifiers.motorStop.indoorVolumeFactor;
		self.sampleMotorStop.indoorLowpassGain = self.soundModifiers.motorStop.indoorVolumeFactor;
		
		for _, modifier in pairs(self.soundModifiers) do
			if modifier.partIndex ~= nil then
				if self.animParts[modifier.partIndex].toMax then -- open
					self.sampleMotor.indoorVolumeFactor = math.max(self.sampleMotor.indoorVolumeFactor, modifier.indoorVolumeFactor);
					self.sampleMotor.indoorLowpassGain = math.max(self.sampleMotor.indoorLowpassGain, modifier.indoorLowpassGain);
					
					self.sampleMotorRun.indoorVolumeFactor = math.max(self.sampleMotorRun.indoorVolumeFactor, modifier.indoorVolumeFactor);
					self.sampleMotorRun.indoorLowpassGain = math.max(self.sampleMotorRun.indoorLowpassGain, modifier.indoorLowpassGain);
					
					self.sampleMotorLoad.indoorVolumeFactor = math.max(self.sampleMotorLoad.indoorVolumeFactor, modifier.indoorVolumeFactor);
					self.sampleMotorLoad.indoorLowpassGain = math.max(self.sampleMotorLoad.indoorLowpassGain, modifier.indoorLowpassGain);
					
					self.sampleMotorStart.indoorVolumeFactor = math.max(self.sampleMotorStart.indoorVolumeFactor, modifier.indoorVolumeFactor);
					self.sampleMotorStart.indoorLowpassGain = math.max(self.sampleMotorStart.indoorLowpassGain, modifier.indoorLowpassGain);
					
					self.sampleMotorStop.indoorVolumeFactor = math.max(self.sampleMotorStop.indoorVolumeFactor, modifier.indoorVolumeFactor);
					self.sampleMotorStop.indoorLowpassGain = math.max(self.sampleMotorStop.indoorLowpassGain, modifier.indoorLowpassGain);
				end;
			end;
		end;
		
		SoundUtil.onCameraSwitched(self.activeCamera.isInside);
		
    end;
end;
function indoorSoundModifier:updateTick(dt)
end;
function indoorSoundModifier:draw()    
end;